use nix::libc;
use serde::Serialize;

pub const INIT_FIFO: &str = "/run/initctl";

pub const INIT_MAGIC: libc::c_int = 0x0309_1969;
pub const INIT_CMD_SETENV: libc::c_int = 6;

pub const DATA_LENGTH: usize = 368;

use crate::util;

/*
 *  Because of legacy interfaces, "runlevel" and "sleeptime"
 *  aren't in a separate struct in the union.
 *
 *  The weird sizes are because init expects the whole
 *  struct to be 384 bytes.
 */
#[repr(C)]
#[derive(Serialize)]
pub struct InitRequest<'a> {
    pub magic: libc::c_int,     // Magic number
    pub cmd: libc::c_int,       // What kind of request
    pub runlevel: libc::c_int,  // Runlevel to change to
    pub sleeptime: libc::c_int, // Time between TERM and KILL
    #[serde(serialize_with = "util::serialize_big_arrays")]
    pub data: &'a [libc::c_uchar; DATA_LENGTH],
}
