use serde::{ser::SerializeTuple as _, Serialize, Serializer};

// Custom serializer for arrays greater than 32 elements.
// This is required as Serde does not support const generics (yet ?).
// See <https://github.com/serde-rs/serde/issues/1937> and <https://stackoverflow.com/a/76695397>.
pub fn serialize_big_arrays<const N: usize, S, T>(
    t: &[T; N],
    serializer: S,
) -> Result<S::Ok, S::Error>
where
    S: Serializer,
    T: Serialize,
{
    let mut ser_tuple = serializer.serialize_tuple(N)?;
    for elem in t {
        ser_tuple.serialize_element(elem)?;
    }
    ser_tuple.end()
}
